@@ -96,9 +96,9 @@ class Department(BaseModel):
         index_together = [
             ["organization_id", "is_deleted"]
         ]
-        unique_together = [
-            "name", "organization_id"
-        ]
+        # unique_together = [
+        #     "name", "organization_id"
+        # ]
 
 
 class DepartmentUserMap(BaseModel):
