@@ -244,7 +244,8 @@ def add_department_user_map(organization_id: int, department_id: int, user_ids:
     return Resp(data="添加成功")
 
 
-def get_department_user(organization_id: int, department_id: int, page: int, size: int):
+# def get_department_user(organization_id: int, department_id: int, page: int, size: int):
+def get_department_user(organization_id: int, department_id: int):
     """
     通过部门获取用户
     :param organization_id: 组织id
@@ -257,19 +258,20 @@ def get_department_user(organization_id: int, department_id: int, page: int, siz
         department__organization_id=organization_id,
         department__is_deleted=False,
         department_id=department_id
-    )
-    total = user_ids.count()
-    max_page = math.ceil(total / size)
-    items = [
-        item for item in user_ids.order_by("-id").values_list("user_id", flat=True)[(page-1)*size: page*size]
-    ] if page <= max_page else []
-
-    return Resp(data={
-        "total": total,
-        "page_range": [i for i in range(1, max_page+1)],
-        "current_page": page,
-        "list": items
-    })
+    ).order_by("-id").values_list("user_id", flat=True)
+    return Resp(data=list(user_ids))
+    # total = user_ids.count()
+    # max_page = math.ceil(total / size)
+    # items = [
+    #     item for item in user_ids.order_by("-id").values_list("user_id", flat=True)[(page-1)*size: page*size]
+    # ] if page <= max_page else []
+    #
+    # return Resp(data={
+    #     "total": total,
+    #     "page_range": [i for i in range(1, max_page+1)],
+    #     "current_page": page,
+    #     "list": items
+    # })
 
 
 def delete_department_user_map(organization_id: int, department_id: int, user_ids: list):
